package androidx.core.graphics.drawable;

import X6FRs_4.Eps4cJe_18.KQgRr5e_0;
import android.content.res.ColorStateList;
import android.os.Parcelable;
/* loaded from: classes.dex */
public class IconCompatParcelizer {
    public static IconCompat read(KQgRr5e_0 kQgRr5e_0) {
        IconCompat iconCompat = new IconCompat();
        iconCompat.KQgRr5e_0 = kQgRr5e_0.KQgRr5e_0(iconCompat.KQgRr5e_0, 1);
        iconCompat.f2248KQgRr5e_0 = kQgRr5e_0.m209KQgRr5e_0(iconCompat.f2248KQgRr5e_0, 2);
        iconCompat.f2245KQgRr5e_0 = kQgRr5e_0.KQgRr5e_0((KQgRr5e_0) iconCompat.f2245KQgRr5e_0, 3);
        iconCompat.f2249QxJ9d_1 = kQgRr5e_0.KQgRr5e_0(iconCompat.f2249QxJ9d_1, 4);
        iconCompat.PGPF6hQ_2 = kQgRr5e_0.KQgRr5e_0(iconCompat.PGPF6hQ_2, 5);
        iconCompat.f2243KQgRr5e_0 = (ColorStateList) kQgRr5e_0.KQgRr5e_0((KQgRr5e_0) iconCompat.f2243KQgRr5e_0, 6);
        iconCompat.f2247KQgRr5e_0 = kQgRr5e_0.KQgRr5e_0(iconCompat.f2247KQgRr5e_0, 7);
        iconCompat.m871KQgRr5e_0();
        return iconCompat;
    }

    public static void write(IconCompat iconCompat, KQgRr5e_0 kQgRr5e_0) {
        kQgRr5e_0.KQgRr5e_0(true, true);
        iconCompat.KQgRr5e_0(kQgRr5e_0.m205KQgRr5e_0());
        int i = iconCompat.KQgRr5e_0;
        if (-1 != i) {
            kQgRr5e_0.m199KQgRr5e_0(i, 1);
        }
        byte[] bArr = iconCompat.f2248KQgRr5e_0;
        if (bArr != null) {
            kQgRr5e_0.KQgRr5e_0(bArr, 2);
        }
        Parcelable parcelable = iconCompat.f2245KQgRr5e_0;
        if (parcelable != null) {
            kQgRr5e_0.m201KQgRr5e_0(parcelable, 3);
        }
        int i2 = iconCompat.f2249QxJ9d_1;
        if (i2 != 0) {
            kQgRr5e_0.m199KQgRr5e_0(i2, 4);
        }
        int i3 = iconCompat.PGPF6hQ_2;
        if (i3 != 0) {
            kQgRr5e_0.m199KQgRr5e_0(i3, 5);
        }
        ColorStateList colorStateList = iconCompat.f2243KQgRr5e_0;
        if (colorStateList != null) {
            kQgRr5e_0.m201KQgRr5e_0((Parcelable) colorStateList, 6);
        }
        String str = iconCompat.f2247KQgRr5e_0;
        if (str != null) {
            kQgRr5e_0.m204KQgRr5e_0(str, 7);
        }
    }
}
